==> opuscodium-sogo-3.1.0.tar.gz: opuscodium-sogo-3.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [3.1.0](https://github.com/opus-codium/puppet-sogo/tree/3.1.0) (2022-09-10)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/3.0.0...3.1.0)

**Implemented enhancements:**

- Add support for Debian 11 [\#36](https://github.com/opus-codium/puppet-sogo/pull/36) ([smortex](https://github.com/smortex))

**Merged pull requests:**

- Allow stdlib 8.x [\#37](https://github.com/opus-codium/puppet-sogo/pull/37) ([smortex](https://github.com/smortex))

## [3.0.0](https://github.com/opus-codium/puppet-sogo/tree/3.0.0) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/2.0.1...3.0.0)

**Breaking changes:**

- Remove Puppet 5 from testing and bump minimal version to 6.0.0 [\#33](https://github.com/opus-codium/puppet-sogo/pull/33) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Update dependencies [\#32](https://github.com/opus-codium/puppet-sogo/pull/32) ([smortex](https://github.com/smortex))
- Add REFERENCE.md [\#27](https://github.com/opus-codium/puppet-sogo/pull/27) ([neomilium](https://github.com/neomilium))
- Document all classes [\#26](https://github.com/opus-codium/puppet-sogo/pull/26) ([smortex](https://github.com/smortex))
- Add a README file [\#25](https://github.com/opus-codium/puppet-sogo/pull/25) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Remove explicit data\_provider from metadata.json [\#29](https://github.com/opus-codium/puppet-sogo/pull/29) ([smortex](https://github.com/smortex))

## [2.0.1](https://github.com/opus-codium/puppet-sogo/tree/2.0.1) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/2.0.0...2.0.1)

**Fixed bugs:**

- Add missing dependency on puppetlabs-stdlib [\#22](https://github.com/opus-codium/puppet-sogo/pull/22) ([smortex](https://github.com/smortex))

## [2.0.0](https://github.com/opus-codium/puppet-sogo/tree/2.0.0) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/1.0.0...2.0.0)

**Implemented enhancements:**

- Ensure string params are not empty [\#16](https://github.com/opus-codium/puppet-sogo/pull/16) ([neomilium](https://github.com/neomilium))
- Remove forbidden undef value on params [\#15](https://github.com/opus-codium/puppet-sogo/pull/15) ([neomilium](https://github.com/neomilium))
- Remove inverse.ca debian repo management [\#14](https://github.com/opus-codium/puppet-sogo/pull/14) ([neomilium](https://github.com/neomilium))
- Start modernization of this old code base [\#2](https://github.com/opus-codium/puppet-sogo/pull/2) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Rename the module sogo3 -\> sogo [\#8](https://github.com/opus-codium/puppet-sogo/pull/8) ([smortex](https://github.com/smortex))

## [1.0.0](https://github.com/opus-codium/puppet-sogo/tree/1.0.0) (2016-11-22)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/ad4f103e09959eb9e4a35aae7f36f672fd0f36ec...1.0.0)

**Fixed bugs:**

- Stop being anoying about no more publicly accessible package repository [\#1](https://github.com/opus-codium/puppet-sogo/pull/1) ([smortex](https://github.com/smortex))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> opuscodium-sogo-4.0.0.tar.gz: opuscodium-sogo-4.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.
Each new release typically also includes the latest modulesync defaults.
These should not affect the functionality of the module.

## [v4.0.0](https://github.com/opus-codium/puppet-sogo/tree/v4.0.0) (2023-07-30)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/v3.1.0...v4.0.0)

**Breaking changes:**

- Drop Puppet 6 \(EOL\) [\#42](https://github.com/opus-codium/puppet-sogo/pull/42) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Add support for Puppet 8 [\#43](https://github.com/opus-codium/puppet-sogo/pull/43) ([smortex](https://github.com/smortex))
- Allow puppetlabs/stdlib 9.x [\#40](https://github.com/opus-codium/puppet-sogo/pull/40) ([smortex](https://github.com/smortex))

## [v3.1.0](https://github.com/opus-codium/puppet-sogo/tree/v3.1.0) (2022-09-12)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/3.0.0...v3.1.0)

**Implemented enhancements:**

- Add support for Debian 11 [\#36](https://github.com/opus-codium/puppet-sogo/pull/36) ([smortex](https://github.com/smortex))

**Merged pull requests:**

- Allow stdlib 8.x [\#37](https://github.com/opus-codium/puppet-sogo/pull/37) ([smortex](https://github.com/smortex))

## [3.0.0](https://github.com/opus-codium/puppet-sogo/tree/3.0.0) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/2.0.1...3.0.0)

**Breaking changes:**

- Remove Puppet 5 from testing and bump minimal version to 6.0.0 [\#33](https://github.com/opus-codium/puppet-sogo/pull/33) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Update dependencies [\#32](https://github.com/opus-codium/puppet-sogo/pull/32) ([smortex](https://github.com/smortex))
- Add REFERENCE.md [\#27](https://github.com/opus-codium/puppet-sogo/pull/27) ([neomilium](https://github.com/neomilium))
- Document all classes [\#26](https://github.com/opus-codium/puppet-sogo/pull/26) ([smortex](https://github.com/smortex))
- Add a README file [\#25](https://github.com/opus-codium/puppet-sogo/pull/25) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Remove explicit data\_provider from metadata.json [\#29](https://github.com/opus-codium/puppet-sogo/pull/29) ([smortex](https://github.com/smortex))

## [2.0.1](https://github.com/opus-codium/puppet-sogo/tree/2.0.1) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/2.0.0...2.0.1)

**Fixed bugs:**

- Add missing dependency on puppetlabs-stdlib [\#22](https://github.com/opus-codium/puppet-sogo/pull/22) ([smortex](https://github.com/smortex))

## [2.0.0](https://github.com/opus-codium/puppet-sogo/tree/2.0.0) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/1.0.0...2.0.0)

**Implemented enhancements:**

- Ensure string params are not empty [\#16](https://github.com/opus-codium/puppet-sogo/pull/16) ([neomilium](https://github.com/neomilium))
- Remove forbidden undef value on params [\#15](https://github.com/opus-codium/puppet-sogo/pull/15) ([neomilium](https://github.com/neomilium))
- Remove inverse.ca debian repo management [\#14](https://github.com/opus-codium/puppet-sogo/pull/14) ([neomilium](https://github.com/neomilium))
- Start modernization of this old code base [\#2](https://github.com/opus-codium/puppet-sogo/pull/2) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Rename the module sogo3 -\> sogo [\#8](https://github.com/opus-codium/puppet-sogo/pull/8) ([smortex](https://github.com/smortex))

## [1.0.0](https://github.com/opus-codium/puppet-sogo/tree/1.0.0) (2016-11-22)

[Full Changelog](https://github.com/opus-codium/puppet-sogo/compare/ad4f103e09959eb9e4a35aae7f36f672fd0f36ec...1.0.0)

**Fixed bugs:**

- Stop being anoying about no more publicly accessible package repository [\#1](https://github.com/opus-codium/puppet-sogo/pull/1) ([smortex](https://github.com/smortex))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
